E CVS: libs/ecore andrunko

2007-12-12 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_imf


Modified Files:
Ecore_IMF.h ecore_imf.c ecore_imf_context.c 


Log Message:
Deleting Ecore_IMF event handlers on _e_entry_smart_del.

===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_imf/Ecore_IMF.h,v
retrieving revision 1.3
retrieving revision 1.4
diff -u -3 -r1.3 -r1.4
--- Ecore_IMF.h 21 Nov 2007 22:20:16 -  1.3
+++ Ecore_IMF.h 12 Dec 2007 19:00:48 -  1.4
@@ -57,7 +57,7 @@
EAPI extern int ECORE_IMF_EVENT_PREEDIT_END;
EAPI extern int ECORE_IMF_EVENT_PREEDIT_CHANGED;
EAPI extern int ECORE_IMF_EVENT_COMMIT;
-   EAPI extern int ECORE_IMF_EVENT_DELETE_SURROUNDIND;
+   EAPI extern int ECORE_IMF_EVENT_DELETE_SURROUNDING;
 
typedef enum
  {
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_imf/ecore_imf.c,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -3 -r1.2 -r1.3
--- ecore_imf.c 22 Nov 2007 11:55:35 -  1.2
+++ ecore_imf.c 12 Dec 2007 19:00:48 -  1.3
@@ -13,8 +13,7 @@
 EAPI int ECORE_IMF_EVENT_PREEDIT_END = 0;
 EAPI int ECORE_IMF_EVENT_PREEDIT_CHANGED = 0;
 EAPI int ECORE_IMF_EVENT_COMMIT = 0;
-EAPI int ECORE_IMF_EVENT_RETRIEVE_SURROUNDIND = 0;
-EAPI int ECORE_IMF_EVENT_DELETE_SURROUNDIND = 0;
+EAPI int ECORE_IMF_EVENT_DELETE_SURROUNDING = 0;
 
 static int init_count = 0;
 
@@ -43,8 +42,7 @@
ECORE_IMF_EVENT_PREEDIT_END = ecore_event_type_new();
ECORE_IMF_EVENT_PREEDIT_CHANGED = ecore_event_type_new();
ECORE_IMF_EVENT_COMMIT = ecore_event_type_new();
-   ECORE_IMF_EVENT_RETRIEVE_SURROUNDIND = ecore_event_type_new();
-   ECORE_IMF_EVENT_DELETE_SURROUNDIND = ecore_event_type_new();
+   ECORE_IMF_EVENT_DELETE_SURROUNDING = ecore_event_type_new();
 
return init_count;
 }
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_imf/ecore_imf_context.c,v
retrieving revision 1.5
retrieving revision 1.6
diff -u -3 -r1.118 -r1.119
--- ecore_evas_x.c  19 Nov 2007 18:27:11 -  1.118
+++ ecore_evas_x.c  30 Nov 2007 17:12:27 -  1.119
@@ -2025,6 +2025,7 @@
 #endif /* BUILD_ECORE_EVAS_X11_16 */
  }
 }
+#endif
 
 static void *
 _ecore_evas_x_window_get(Ecore_Evas *ee)
@@ -2036,6 +2037,7 @@
 #endif
 }
 
+#ifdef BUILD_ECORE_EVAS_X11
 static void
 _ecore_evas_x_show(Ecore_Evas *ee)
 {



-
SF.Net email is sponsored by: The Future of Linux Business White Paper
from Novell.  From the desktop to the data center, Linux is going
mainstream.  Let it simplify your IT future.
http://altfarm.mediaplex.com/ad/ck/8857-50307-18918-4
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-21 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_imf_evas




Log Message:
Directory /cvs/e/e17/libs/ecore/src/lib/ecore_imf_evas added to the repository




-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-21 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_imf_evas


Added Files:
.cvsignore Ecore_IMF_Evas.h Makefile.am ecore_imf_evas.c 


Log Message:
Added Ecore_IMF_Evas.

Removed Evas dependency from Ecore_IMF, that was requested by Ewl developers
in order to be able to integrate Ecore_IMF on it.

Added Ecore_IMF_Evas, a library with helper functions to use Ecore_IMF together
with Evas.

Now everybody should be happy.




-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-21 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib


Modified Files:
Makefile.am 


Log Message:
Added Ecore_IMF_Evas.

Removed Evas dependency from Ecore_IMF, that was requested by Ewl developers
in order to be able to integrate Ecore_IMF on it.

Added Ecore_IMF_Evas, a library with helper functions to use Ecore_IMF together
with Evas.

Now everybody should be happy.

===
RCS file: /cvs/e/e17/libs/ecore/src/lib/Makefile.am,v
retrieving revision 1.14
retrieving revision 1.15
diff -u -3 -r1.14 -r1.15
--- Makefile.am 19 Nov 2007 18:27:11 -  1.14
+++ Makefile.am 21 Nov 2007 22:20:16 -  1.15
@@ -14,4 +14,5 @@
 ecore_config \
 ecore_file \
 ecore_desktop \
-ecore_imf
+ecore_imf \
+ecore_imf_evas



-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-21 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_imf


Modified Files:
Ecore_IMF.h Makefile.am ecore_imf_context.c ecore_imf_module.c 
ecore_imf_private.h 


Log Message:
Added Ecore_IMF_Evas.

Removed Evas dependency from Ecore_IMF, that was requested by Ewl developers
in order to be able to integrate Ecore_IMF on it.

Added Ecore_IMF_Evas, a library with helper functions to use Ecore_IMF together
with Evas.

Now everybody should be happy.

===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_imf/Ecore_IMF.h,v
retrieving revision 1.2
retrieving revision 1.3
diff -u -3 -r1.2 -r1.3
--- Ecore_IMF.h 21 Nov 2007 01:33:50 -  1.2
+++ Ecore_IMF.h 21 Nov 2007 22:20:16 -  1.3
@@ -26,18 +26,29 @@
 #endif
 
 #include Ecore_Data.h
-#include Evas.h
 
 #ifdef __cplusplus
 extern C {
 #endif
 
+   /* Events sent by the Input Method */
typedef struct _Ecore_IMF_Event_Preedit_Start  
Ecore_IMF_Event_Preedit_Start;
typedef struct _Ecore_IMF_Event_Preedit_End
Ecore_IMF_Event_Preedit_End;
typedef struct _Ecore_IMF_Event_Preedit_Changed
Ecore_IMF_Event_Preedit_Changed;
typedef struct _Ecore_IMF_Event_Commit Ecore_IMF_Event_Commit;
typedef struct _Ecore_IMF_Event_Delete_Surrounding 
Ecore_IMF_Event_Delete_Surrounding;
 
+   /* Events to filter */
+   typedef struct _Ecore_IMF_Event_Mouse_Down 
Ecore_IMF_Event_Mouse_Down;
+   typedef struct _Ecore_IMF_Event_Mouse_Up   Ecore_IMF_Event_Mouse_Up;
+   typedef struct _Ecore_IMF_Event_Mouse_In   Ecore_IMF_Event_Mouse_In;
+   typedef struct _Ecore_IMF_Event_Mouse_Out  
Ecore_IMF_Event_Mouse_Out;
+   typedef struct _Ecore_IMF_Event_Mouse_Move 
Ecore_IMF_Event_Mouse_Move;
+   typedef struct _Ecore_IMF_Event_Mouse_Wheel
Ecore_IMF_Event_Mouse_Wheel;
+   typedef struct _Ecore_IMF_Event_Key_Down   Ecore_IMF_Event_Key_Down;
+   typedef struct _Ecore_IMF_Event_Key_Up Ecore_IMF_Event_Key_Up;
+   typedef union  _Ecore_IMF_EventEcore_IMF_Event;
+
typedef struct _Ecore_IMF_Context  Ecore_IMF_Context;   
   /** An Input Method Context */
typedef struct _Ecore_IMF_Context_ClassEcore_IMF_Context_Class; 
   /** An Input Method Context class */
typedef struct _Ecore_IMF_Context_Info Ecore_IMF_Context_Info;  
   /** An Input Method Context info */
@@ -50,6 +61,42 @@
 
typedef enum
  {
+   ECORE_IMF_EVENT_MOUSE_DOWN,
+   ECORE_IMF_EVENT_MOUSE_UP,
+   ECORE_IMF_EVENT_MOUSE_IN,
+   ECORE_IMF_EVENT_MOUSE_OUT,
+   ECORE_IMF_EVENT_MOUSE_MOVE,
+   ECORE_IMF_EVENT_MOUSE_WHEEL,
+   ECORE_IMF_EVENT_KEY_DOWN,
+   ECORE_IMF_EVENT_KEY_UP
+ } Ecore_IMF_Event_Type;
+
+   typedef enum
+ {
+   ECORE_IMF_KEYBOARD_MODIFIER_NONE  = 0,  /** No active modifiers */
+   ECORE_IMF_KEYBOARD_MODIFIER_CTRL  = 1  0, /** Control is pressed */
+   ECORE_IMF_KEYBOARD_MODIFIER_ALT   = 1  1, /** Alt is pressed */
+   ECORE_IMF_KEYBOARD_MODIFIER_SHIFT = 1  2, /** Shift is pressed */
+   ECORE_IMF_KEYBOARD_MODIFIER_WIN   = 1  3  /** Win (between Ctrl 
and Alt) is pressed */
+ } Ecore_IMF_Keyboard_Modifiers;
+
+   typedef enum
+ {
+   ECORE_IMF_KEYBOARD_LOCK_NONE  = 0,  /** No locks are active */
+   ECORE_IMF_KEYBOARD_LOCK_NUM   = 1  0, /** Num lock is active */
+   ECORE_IMF_KEYBOARD_LOCK_CAPS  = 1  1, /** Caps lock is active 
*/
+   ECORE_IMF_KEYBOARD_LOCK_SCROLL= 1  2  /** Scroll lock is 
active */
+ } Ecore_IMF_Keyboard_Locks;
+
+   typedef enum
+ {
+   ECORE_IMF_MOUSE_NONE  = 0,  /** A single click */
+   ECORE_IMF_MOUSE_DOUBLE_CLICK  = 1  0, /** A double click */
+   ECORE_IMF_MOUSE_TRIPLE_CLICK  = 1  1  /** A triple click */
+ } Ecore_IMF_Mouse_Flags;
+
+   typedef enum
+ {
ECORE_IMF_INPUT_MODE_ALPHA= 1  0,
ECORE_IMF_INPUT_MODE_NUMERIC  = 1  1,
ECORE_IMF_INPUT_MODE_SPECIAL  = 1  2,
@@ -88,11 +135,135 @@
int n_chars;
  };
 
+   struct _Ecore_IMF_Event_Mouse_Down
+ {
+   int button; /** The button which has been 
pressed */
+   struct {
+int x, y;
+   } output;
+   struct {
+int x, y;
+   } canvas;
+   Ecore_IMF_Keyboard_Modifiers modifiers; /** The keyboard modifiers 
active when the event has been emitted */
+   Ecore_IMF_Keyboard_Locks locks; /** The keyboard locks active 
when the event has been emitted */
+   Ecore_IMF_Mouse_Flagsflags; /** The flags corresponding 
the mouse click (single, double or triple click) */
+   unsigned int timestamp; /** The timestamp when the 
event occured */
+ };
+
+   struct 

E CVS: libs/ecore andrunko

2007-11-21 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore


Modified Files:
Makefile.am configure.in ecore-imf.pc.in 
Added Files:
ecore-imf-evas.pc.in 


Log Message:
Added Ecore_IMF_Evas.

Removed Evas dependency from Ecore_IMF, that was requested by Ewl developers
in order to be able to integrate Ecore_IMF on it.

Added Ecore_IMF_Evas, a library with helper functions to use Ecore_IMF together
with Evas.

Now everybody should be happy.

===
RCS file: /cvs/e/e17/libs/ecore/Makefile.am,v
retrieving revision 1.40
retrieving revision 1.41
diff -u -3 -r1.40 -r1.41
--- Makefile.am 19 Nov 2007 18:27:10 -  1.40
+++ Makefile.am 21 Nov 2007 22:20:15 -  1.41
@@ -17,6 +17,7 @@
   ecore-fb.pc \
   ecore-file.pc \
   ecore-imf.pc \
+  ecore-imf-evas.pc \
   ecore-ipc.pc \
   ecore-job.pc \
   ecore-txt.pc \
@@ -38,6 +39,7 @@
 ecore-fb.pc.in \
 ecore-file.pc.in \
 ecore-imf.pc.in \
+ecore-imf-evas.pc.in \
 ecore-ipc.pc.in \
 ecore-job.pc.in \
 ecore-txt.pc.in \
@@ -79,6 +81,10 @@
 pimf = ecore-imf.pc
 endif
 
+if BUILD_ECORE_IMF_EVAS
+pimfevas = ecore-imf-evas.pc
+endif
+
 if BUILD_ECORE_IPC
 pipc = ecore-ipc.pc
 endif
@@ -111,5 +117,5 @@
 pkgconfigdir = $(libdir)/pkgconfig
 pkgconfig_DATA = \
ecore.pc $(pcon) $(pconfig) $(pdfb) $(pevas) \
-   $(pfb) $(pfile) $(pdesktop) $(pimf) $(pipc) $(pjob) $(ptxt) \
+   $(pfb) $(pfile) $(pdesktop) $(pimf) $(pimfevas) $(pipc) $(pjob) $(ptxt) 
\
$(px) $(pwin32) $(psdl)
===
RCS file: /cvs/e/e17/libs/ecore/configure.in,v
retrieving revision 1.242
retrieving revision 1.243
diff -u -3 -r1.242 -r1.243
--- configure.in21 Nov 2007 12:16:16 -  1.242
+++ configure.in21 Nov 2007 22:20:15 -  1.243
@@ -715,7 +715,14 @@
   [requirements_ecore_desktop=ecore-file])
 
 dnl ecore_imf
-ECORE_CHECK_MODULE([IMF], [yes], [$have_evas])
+ECORE_CHECK_MODULE([IMF], [yes])
+
+try_ecore_imf_evas=no
+if test x$have_ecore_imf = xyes -a x$have_evas = xyes; then
+  try_ecore_imf_evas=yes
+fi
+
+ECORE_CHECK_MODULE([IMF_EVAS], [yes], [$try_ecore_imf_evas])
 
 dnl requirements
 AC_SUBST(requirements_ecore_con)
@@ -752,6 +759,7 @@
 ecore-fb.pc
 ecore-file.pc
 ecore-imf.pc
+ecore-imf-evas.pc
 ecore-ipc.pc
 ecore-job.pc
 ecore-txt.pc
@@ -770,6 +778,7 @@
 src/lib/ecore_evas/Makefile
 src/lib/ecore_con/Makefile
 src/lib/ecore_imf/Makefile
+src/lib/ecore_imf_evas/Makefile
 src/lib/ecore_ipc/Makefile
 src/lib/ecore_txt/Makefile
 src/lib/ecore_config/Makefile
@@ -816,6 +825,7 @@
 echo   Ecore_Desktop: $have_ecore_desktop
 
 echo   Ecore_IMF: $have_ecore_imf
+echo   Ecore_IMF_Evas...: $have_ecore_imf_evas
 echo
 echo Now type 'make' ('gmake' on some systems) to compile $PACKAGE.
 echo
===
RCS file: /cvs/e/e17/libs/ecore/ecore-imf.pc.in,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
--- ecore-imf.pc.in 19 Nov 2007 18:27:11 -  1.1
+++ ecore-imf.pc.in 21 Nov 2007 22:20:15 -  1.2
@@ -5,7 +5,7 @@
 
 Name: ecore-imf
 Description: E core library, IMF module
-Requires: ecore evas
+Requires: ecore
 Version: @VERSION@
 Libs: -L${libdir} -lecore_imf
 Cflags: -I${includedir}



-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-20 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_imf


Modified Files:
Ecore_IMF.h ecore_imf_context.c 


Log Message:
Changed ecore_imf_context_client_window_set to receive an Evas pointer.

This would allow applications to create input method plugins with more
fancy stuff (like transparency, ...).
See http://staff.get-e.org/?p=users/andrunko/ilike-imf-ecore.git;a=summary.

===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_imf/Ecore_IMF.h,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
--- Ecore_IMF.h 19 Nov 2007 18:27:11 -  1.1
+++ Ecore_IMF.h 21 Nov 2007 01:33:50 -  1.2
@@ -92,7 +92,7 @@
  {
void (*add) (Ecore_IMF_Context *ctx);
void (*del) (Ecore_IMF_Context *ctx);
-   void (*client_window_set)   (Ecore_IMF_Context *ctx, void *window);
+   void (*client_window_set)   (Ecore_IMF_Context *ctx, Evas *evas);
void (*show)(Ecore_IMF_Context *ctx);
void (*hide)(Ecore_IMF_Context *ctx);
void (*preedit_string_get)  (Ecore_IMF_Context *ctx, char **str, int 
*cursor_pos);
@@ -121,7 +121,7 @@
 
EAPI Ecore_IMF_Context*ecore_imf_context_add(const char *id);
EAPI void  ecore_imf_context_del(Ecore_IMF_Context 
*ctx);
-   EAPI void  
ecore_imf_context_client_window_set(Ecore_IMF_Context *ctx, void *window);
+   EAPI void  
ecore_imf_context_client_window_set(Ecore_IMF_Context *ctx, Evas *evas);
EAPI void  ecore_imf_context_show(Ecore_IMF_Context 
*ctx);
EAPI void  ecore_imf_context_hide(Ecore_IMF_Context 
*ctx);
EAPI void  
ecore_imf_context_preedit_string_get(Ecore_IMF_Context *ctx, char **str, int 
*cursor_pos);
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_imf/ecore_imf_context.c,v
retrieving revision 1.1
retrieving revision 1.2
diff -u -3 -r1.1 -r1.2
--- ecore_imf_context.c 19 Nov 2007 18:27:11 -  1.1
+++ ecore_imf_context.c 21 Nov 2007 01:33:50 -  1.2
@@ -183,7 +183,7 @@
 
 /**
  * Set the client window for the Input Method Context; this is the
- * window returned by ecore_evas_window_get() in which the input appears.
+ * Evas canvas in which the input appears.
  * This window is used in order to correctly position status windows, and may
  * also be used for purposes internal to the Input Method Context.
  *
@@ -193,7 +193,7 @@
  * @ingroup Ecore_IMF_Context_Group
  */
 EAPI void
-ecore_imf_context_client_window_set(Ecore_IMF_Context *ctx, void *window)
+ecore_imf_context_client_window_set(Ecore_IMF_Context *ctx, Evas *evas)
 {
if (!ECORE_MAGIC_CHECK(ctx, ECORE_MAGIC_CONTEXT))
  {
@@ -201,7 +201,7 @@
 ecore_imf_context_client_window_set);
return;
  }
-   if (ctx-klass-client_window_set) ctx-klass-client_window_set(ctx, 
window);
+   if (ctx-klass-client_window_set) ctx-klass-client_window_set(ctx, evas);
 }
 
 /**



-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-19 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_imf




Log Message:
Directory /cvs/e/e17/libs/ecore/src/lib/ecore_imf added to the repository




-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-19 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_evas


Modified Files:
Ecore_Evas.h ecore_evas.c ecore_evas_buffer.c 
ecore_evas_directfb.c ecore_evas_fb.c ecore_evas_private.h 
ecore_evas_sdl.c ecore_evas_win32.c ecore_evas_x.c 


Log Message:
Added Ecore_IMF module.

Added Ecore_IMF module. This module enables different input methods to be
used with Ecore. Input methods modules can be created using the Ecore_IMF
interface.
Added ecore_evas_window_get method to allow input methods to request
the window related to a given Ecore_Evas when available.

===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_evas/Ecore_Evas.h,v
retrieving revision 1.34
retrieving revision 1.35
diff -u -3 -r1.34 -r1.35
--- Ecore_Evas.h5 Nov 2007 20:23:39 -   1.34
+++ Ecore_Evas.h19 Nov 2007 18:27:11 -  1.35
@@ -232,6 +232,7 @@
 EAPI int ecore_evas_sticky_get(Ecore_Evas *ee);
 EAPI voidecore_evas_ignore_events_set(Ecore_Evas *ee, int ignore);
 EAPI int ecore_evas_ignore_events_get(Ecore_Evas *ee);
+EAPI void   *ecore_evas_window_get(Ecore_Evas *ee);
 
 #ifdef __cplusplus
 }
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_evas/ecore_evas.c,v
retrieving revision 1.43
retrieving revision 1.44
diff -u -3 -r1.43 -r1.44
--- ecore_evas.c6 Nov 2007 07:21:08 -   1.43
+++ ecore_evas.c19 Nov 2007 18:27:11 -  1.44
@@ -1773,6 +1773,20 @@
   return ee-ignore_events ? 1 : 0;
 }
 
+EAPI void *
+ecore_evas_window_get(Ecore_Evas *ee)
+{
+   if (!ECORE_MAGIC_CHECK(ee, ECORE_MAGIC_EVAS))
+   {
+  ECORE_MAGIC_FAIL(ee, ECORE_MAGIC_EVAS,
+ ecore_evas_window_get);
+  return NULL;
+   }
+
+   if (ee-engine.func-fn_window_get) return 
ee-engine.func-fn_window_get(ee);
+   return NULL;
+}
+
 #ifndef _WIN32
 /* fps debug calls - for debugging how much time your app actually spends */
 /* rendering graphics... :) */
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_evas/ecore_evas_buffer.c,v
retrieving revision 1.17
retrieving revision 1.18
diff -u -3 -r1.17 -r1.18
--- ecore_evas_buffer.c 26 Aug 2007 11:17:21 -  1.17
+++ ecore_evas_buffer.c 19 Nov 2007 18:27:11 -  1.18
@@ -425,6 +425,7 @@
  NULL,
  NULL,
  NULL,
+ NULL,
  NULL
 };
 #endif
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_evas/ecore_evas_directfb.c,v
retrieving revision 1.12
retrieving revision 1.13
diff -u -3 -r1.12 -r1.13
--- ecore_evas_directfb.c   26 Sep 2007 15:41:50 -  1.12
+++ ecore_evas_directfb.c   19 Nov 2007 18:27:11 -  1.13
@@ -497,8 +497,19 @@
if(ee-func.fn_resize) ee-func.fn_resize(ee);
  }
 }
+#endif
 
+static void *
+_ecore_evas_directfb_window_get(Ecore_Evas *ee)
+{
+#ifdef BUILD_ECORE_EVAS_DIRECTFB
+   return ee-engine.directfb.window;
+#else
+   return 0;
+#endif
+}
 
+#ifdef BUILD_ECORE_EVAS_DIRECTFB
 static const Ecore_Evas_Engine_Func _ecore_directfb_engine_func =
 {
_ecore_evas_directfb_free,  /* free an ecore_evas */
@@ -544,7 +555,8 @@
  NULL, /* withdrawn */
  NULL, /* sticky */
  NULL,  /* ignore events */
- NULL   /* alpha */
+ NULL,  /* alpha */
+ _ecore_evas_directfb_window_get/* window_get */
 };
 #endif
 
@@ -554,15 +566,9 @@
 Ecore_DirectFB_Window *
 ecore_evas_directfb_window_get(Ecore_Evas *ee)
 {
-#ifdef BUILD_ECORE_EVAS_DIRECTFB
-   return ee-engine.directfb.window;
-#else
-   ee = NULL;
-   return NULL;
-#endif   
+   return (Ecore_DirectFB_Window *) _ecore_evas_directfb_window_get(ee);
 }
 
-   
 EAPI Ecore_Evas *
 ecore_evas_directfb_new(const char *disp_name, int windowed, int x, int y, int 
w, int h)
 {
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_evas/ecore_evas_fb.c,v
retrieving revision 1.31
retrieving revision 1.32
diff -u -3 -r1.31 -r1.32
--- ecore_evas_fb.c 19 Nov 2007 08:42:33 -  1.31
+++ ecore_evas_fb.c 19 Nov 2007 18:27:11 -  1.32
@@ -557,6 +557,7 @@
  _ecore_evas_fullscreen_set,
  NULL,
  NULL,
+ NULL,
  NULL
 };
 #endif
===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_evas/ecore_evas_private.h,v
retrieving revision 1.36
retrieving revision 1.37
diff -u -3 -r1.36 -r1.37
--- ecore_evas_private.h6 Nov 2007 07:21:08 -   1.36
+++ ecore_evas_private.h19 Nov 2007 18:27:11 -  1.37
@@ -124,6 +124,7 @@
void(*fn_sticky_set) 

E CVS: libs/ecore andrunko

2007-11-19 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_imf


Added Files:
.cvsignore Ecore_IMF.h Makefile.am ecore_imf.c 
ecore_imf_context.c ecore_imf_module.c ecore_imf_private.h 


Log Message:
Added Ecore_IMF module.

Added Ecore_IMF module. This module enables different input methods to be
used with Ecore. Input methods modules can be created using the Ecore_IMF
interface.
Added ecore_evas_window_get method to allow input methods to request
the window related to a given Ecore_Evas when available.




-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-19 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore


Modified Files:
Makefile.am configure.in 
Added Files:
ecore-imf.pc.in 


Log Message:
Added Ecore_IMF module.

Added Ecore_IMF module. This module enables different input methods to be
used with Ecore. Input methods modules can be created using the Ecore_IMF
interface.
Added ecore_evas_window_get method to allow input methods to request
the window related to a given Ecore_Evas when available.

===
RCS file: /cvs/e/e17/libs/ecore/Makefile.am,v
retrieving revision 1.39
retrieving revision 1.40
diff -u -3 -r1.39 -r1.40
--- Makefile.am 7 Nov 2007 22:56:04 -   1.39
+++ Makefile.am 19 Nov 2007 18:27:10 -  1.40
@@ -16,6 +16,7 @@
   ecore-evas.pc \
   ecore-fb.pc \
   ecore-file.pc \
+  ecore-imf.pc \
   ecore-ipc.pc \
   ecore-job.pc \
   ecore-txt.pc \
@@ -36,6 +37,7 @@
 ecore-evas.pc.in \
 ecore-fb.pc.in \
 ecore-file.pc.in \
+ecore-imf.pc.in \
 ecore-ipc.pc.in \
 ecore-job.pc.in \
 ecore-txt.pc.in \
@@ -73,6 +75,10 @@
 pdesktop = ecore-desktop.pc
 endif
 
+if BUILD_ECORE_IMF
+pimf = ecore-imf.pc
+endif
+
 if BUILD_ECORE_IPC
 pipc = ecore-ipc.pc
 endif
@@ -105,5 +111,5 @@
 pkgconfigdir = $(libdir)/pkgconfig
 pkgconfig_DATA = \
ecore.pc $(pcon) $(pconfig) $(pdfb) $(pevas) \
-   $(pfb) $(pfile) $(pdesktop) $(pipc) $(pjob) $(ptxt) \
+   $(pfb) $(pfile) $(pdesktop) $(pimf) $(pipc) $(pjob) $(ptxt) \
$(px) $(pwin32) $(psdl)
===
RCS file: /cvs/e/e17/libs/ecore/configure.in,v
retrieving revision 1.240
retrieving revision 1.241
diff -u -3 -r1.240 -r1.241
--- configure.in17 Nov 2007 13:49:47 -  1.240
+++ configure.in19 Nov 2007 18:27:11 -  1.241
@@ -704,6 +704,9 @@
 ECORE_CHECK_MODULE([Desktop], [no], [$have_ecore_file],
   [requirements_ecore_desktop=ecore-file])
 
+dnl ecore_imf
+ECORE_CHECK_MODULE([IMF], [yes], [$have_evas])
+
 dnl requirements
 AC_SUBST(requirements_ecore_con)
 AC_SUBST(requirements_ecore_config)
@@ -738,6 +741,7 @@
 ecore-evas.pc
 ecore-fb.pc
 ecore-file.pc
+ecore-imf.pc
 ecore-ipc.pc
 ecore-job.pc
 ecore-txt.pc
@@ -755,6 +759,7 @@
 src/lib/ecore_sdl/Makefile
 src/lib/ecore_evas/Makefile
 src/lib/ecore_con/Makefile
+src/lib/ecore_imf/Makefile
 src/lib/ecore_ipc/Makefile
 src/lib/ecore_txt/Makefile
 src/lib/ecore_config/Makefile
@@ -799,6 +804,8 @@
 
 echo   Ecore_File...: $have_ecore_file (Inotify: 
$have_inotify) (Poll: $have_poll) (CURL: $have_curl)
 echo   Ecore_Desktop: $have_ecore_desktop
+
+echo   Ecore_IMF: $have_ecore_imf
 echo
 echo Now type 'make' ('gmake' on some systems) to compile $PACKAGE.
 echo



-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-19 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib


Modified Files:
Makefile.am 


Log Message:
Added Ecore_IMF module.

Added Ecore_IMF module. This module enables different input methods to be
used with Ecore. Input methods modules can be created using the Ecore_IMF
interface.
Added ecore_evas_window_get method to allow input methods to request
the window related to a given Ecore_Evas when available.

===
RCS file: /cvs/e/e17/libs/ecore/src/lib/Makefile.am,v
retrieving revision 1.13
retrieving revision 1.14
diff -u -3 -r1.13 -r1.14
--- Makefile.am 26 Aug 2007 11:17:20 -  1.13
+++ Makefile.am 19 Nov 2007 18:27:11 -  1.14
@@ -13,4 +13,5 @@
 ecore_evas \
 ecore_config \
 ecore_file \
-ecore_desktop
+ecore_desktop \
+ecore_imf



-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-09-30 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore


Modified Files:
configure.in 


Log Message:
Fixed configure on maemo.

===
RCS file: /cvs/e/e17/libs/ecore/configure.in,v
retrieving revision 1.214
retrieving revision 1.215
diff -u -3 -r1.214 -r1.215
--- configure.in26 Sep 2007 17:14:27 -  1.214
+++ configure.in30 Sep 2007 15:31:13 -  1.215
@@ -618,7 +618,7 @@
 if test x$have_ecore_evas_sdl = xyes; then
   PKG_CHECK_MODULES(SDL, sdl = 1.3.0,
 [ AC_DEFINE(BUILD_ECORE_EVAS_SDL_130, 1, [Support for SVN SDL]) ],
-[ dummy=no ]);
+[ dummy=no ])
 fi
 
 AC_SUBST(sdl_cflags)



-
This SF.net email is sponsored by: Microsoft
Defy all challenges. Microsoft(R) Visual Studio 2005.
http://clk.atdmt.com/MRT/go/vse012070mrt/direct/01/
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs
diff -u -3 -r1.5 -r1.6
--- ecore_imf_context.c 22 Nov 2007 11:57:01 -  1.5
+++ ecore_imf_context.c 12 Dec 2007 19:00:48 -  1.6
@@ -773,7 +773,7 @@
 }
 
 /**
  * Adds ECORE_IMF_EVENT_DELETE_SURROUNDIND to the event queue.
  *
  * @param ctx An #Ecore_IMF_Context.
  * @param offset The start offset of surrounding to be deleted.
@@ -796,6 +796,6 @@
ev-ctx = ctx;
ev-offset = offset;
ev-n_chars = n_chars;
-   ecore_event_add(ECORE_IMF_EVENT_DELETE_SURROUNDIND,
+   ecore_event_add(ECORE_IMF_EVENT_DELETE_SURROUNDING,
   ev, _ecore_imf_event_free_delete_surrounding, NULL);
 }



-
@@ -773,7 +773,7 @@
 
 /**
- * Adds ECORE_IMF_EVENT_DELETE_SURROUNDIND to the event queue.
+ * Adds ECORE_IMF_EVENT_DELETE_SURROUNDING to the event queue.
  *
  * @param ctx An #Ecore_IMF_Context.
SF.Net email is sponsored by:
Check out the new SourceForge.net Marketplace.
It's the best place to buy or sell services
for just about anything Open Source.
http://ad.doubleclick.net/clk;164216239;13503038;w?http://sf.net/marketplace
___
enlightenment-cvs mailing list
enlightenment-cvs@lists.sourceforge.net
https://lists.sourceforge.net/lists/listinfo/enlightenment-cvs


E CVS: libs/ecore andrunko

2007-11-30 Thread Enlightenment CVS
Enlightenment CVS committal

Author  : andrunko
Project : e17
Module  : libs/ecore

Dir : e17/libs/ecore/src/lib/ecore_evas


Modified Files:
ecore_evas_x.c 


Log Message:
Fixed undefined symbol when BUILD_ECORE_EVAS_X11 is not set.

===
RCS file: /cvs/e/e17/libs/ecore/src/lib/ecore_evas/ecore_evas_x.c,v
retrieving revision 1.118
retrieving revision 1.119